==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/elasticache/kotlin/inputs/GetSubnetGroupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elasticache.kotlin.inputs

import com.pulumi.aws.elasticache.inputs.GetSubnetGroupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getSubnetGroup.
 * @property name Name of the subnet group.
 * @property tags Map of tags assigned to the subnet group.
 */
public data class GetSubnetGroupPlainArgs(
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.elasticache.inputs.GetSubnetGroupPlainArgs> {
    override fun toJava(): com.pulumi.aws.elasticache.inputs.GetSubnetGroupPlainArgs =
        com.pulumi.aws.elasticache.inputs.GetSubnetGroupPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetSubnetGroupPlainArgs].
 */
@PulumiTagMarker
public class GetSubnetGroupPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the subnet group.
     */
    @JvmName("vlbrlerqhlwbgmvk")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags assigned to the subnet group.
     */
    @JvmName("hednfmkgqpheuoga")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags assigned to the subnet group.
     */
    @JvmName("ckandsxpaqqcfkpe")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetSubnetGroupPlainArgs = GetSubnetGroupPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/elasticache/kotlin/inputs/GetSubnetGroupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elasticache.kotlin.inputs

import com.pulumi.aws.elasticache.inputs.GetSubnetGroupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getSubnetGroup.
 * @property name Name of the subnet group.
 * @property tags Map of tags assigned to the subnet group.
 */
public data class GetSubnetGroupPlainArgs(
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.elasticache.inputs.GetSubnetGroupPlainArgs> {
    override fun toJava(): com.pulumi.aws.elasticache.inputs.GetSubnetGroupPlainArgs =
        com.pulumi.aws.elasticache.inputs.GetSubnetGroupPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetSubnetGroupPlainArgs].
 */
@PulumiTagMarker
public class GetSubnetGroupPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the subnet group.
     */
    @JvmName("ojqvwepmldahnmic")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags assigned to the subnet group.
     */
    @JvmName("shxdepbsakjxqrdd")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags assigned to the subnet group.
     */
    @JvmName("mcgujwoebrvpnhwr")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetSubnetGroupPlainArgs = GetSubnetGroupPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}
